| Title: | A GUI to View, Design and Export Various Graphs of Data |
|---|---|
| Description: | Provides a graphical user interface for viewing and designing various types of graphs of the data. The graphs can be saved in different formats of an image. |
| Authors: | Dhammapal Bharne, Vaibhav Vindal |
| Maintainer: | Dhammapal Bharne <[email protected]> |
| License: | GPL-2 |
| Version: | 2.0 |
| Built: | 2026-05-28 14:46:43 UTC |
| Source: | https://github.com/cran/plfMA |
Provides a graphical user interface for viewing, designing and exporting various types of graphs of the data. A table file can be directly imported for visualization after launching the GUI. A data object with graph type can also be passed to library function. A graph type could be either scatter (scatter-plot), hist (histogram), bar (bar-plot), box (box-plot), pie (pie-diagram), 3d (3d-plot), ma (MA-plot), density (density-plot) or heatmap. The graphs can be designed with different labels, colors, sizes and other features and saved at differnt resolution in bmp, jpeg, png, tiff, pdf and postscript formats.
| Package: | plfMA |
| Type: | Package |
| Version: | 2.0 |
| Date: | 2022-01-07 |
| License: | GPL-2 |
Just type pflMA() at R prompt to launch the GUI. Alternatively, create a data object such as x at R prompt and launch the GUI by typing plfMA(x,"heatmap") for heatmap.
Maintainer: Dhammapal Bharne <[email protected]>
A function to launch the plfMA GUI.
plfMA(h,gtype,...)plfMA(h,gtype,...)
h |
Data matrix, data frame, RGList, MAList or Empty |
gtype |
Graph type or Empty if h is empty |
... |
Other arguments for h object or Empty |
Once the package is loaded with library function, the GUI can be launced using this function.
Dhammapal Bharne & Vaibhav Vindal, Department of Biotechnology and Bioinformatics, School of Life Sciences, University of Hyderabad, Hyderabad, Telangana, India.
x<-matrix(1:60,ncol=6) plfMA(x,gtype="heatmap")x<-matrix(1:60,ncol=6) plfMA(x,gtype="heatmap")